Samyro
=======================

An automatic poetry organizer built on `TensorFlow <http://tensorflow.org>`_'s
RNNs.

Samyro learns a text style from examples, saving
checkpoints, and generating new text segments from those samples.
Derived from example code built for PrettyTensor.

"Samyro" was the first pseudonym of Samuel (Samy) Rosenstock, better
known by his later pseudonym `Tristan Tzara
<http://en.wikipedia.org/Tristan_Tzara>`_. (`tzara` was already taken
on pypi.)


Contributing
============

Unstable vx.x.x-dev branches are maintained for the next version to be
released on master at github.  Please submit pull requests to the new
dev branches if possible, but pull requests against master will also
be gladly integrated.

Feature request lists are currently in TODO.rst (part of this
distribution) but may migrate to github issues if that makes it easier
for others to contribute.
